@@ -54,7 +54,7 @@ class Client:
         asyncio.ensure_future(self.session_manager.session_pool.run())
 
     async def on_message(self, ws, message):
-        logger.info("on_message: %s" % message)
+        logger.debug("on_message: %s" % message)
         message_event = json.loads(message)
         if await self._is_system_event(message_event, ws):
             return
@@ -135,7 +135,7 @@ class Client:
         :param event_json:
         """
         send_msg = event_json
-        logger.info("send_msg: %s" % send_msg)
+        logger.debug("send_msg: %s" % send_msg)
         if isinstance(self.ws_conn, ClientWebSocketResponse):
             if self.ws_conn.closed:
                 logger.error("send_msg: websocket connection has closed")
